==> crm-commom-vo-1.1.9.47.release.jar: com/biz/crm/nebular/dms/repfeepool/ListUsedRes.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.PageVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/10/21 16:43
 **/
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "前段页面查货补扣减记录返回的vo")
public class ListUsedRes extends PageVo {

    @ApiModelProperty(value = "来源编码")
    private String resourceCode;

    @ApiModelProperty(value = "编码")
    private String code;

    @ApiModelProperty(value = "销售公司名字")
    private String saleConpaneyName;

    @ApiModelProperty(value = "类型中文")
    private Integer type;

    @CrmDict(typeCode="notice_msg_state",dictCodeField="type")
    @ApiModelProperty(value = "类型中文")
    private String typeName;

    @ApiModelProperty(value = "订单编号")
    private String orderCode;

    @ApiModelProperty(value = "产品编码")
    private String productCode;

    @ApiModelProperty(value = "产品名称")
    private String productName;

    @ApiModelProperty(value = "单价")
    private BigDecimal price;

    @ApiModelProperty(value = "单位")
    private String unit;

    @ApiModelProperty(value = "数量")
    private BigDecimal num;

    @ApiModelProperty(value = "日期")
    private String happenDate;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "附件地址")
    private List<String> fileUrls = new ArrayList<>();

    @ApiModelProperty(value = "创建时间（日期+时间）")
    private String createTime;

    @ApiModelProperty(value = "创建人名称")
    private String createName;
}

==> crm-commom-vo-1.2.2.release.jar: com/biz/crm/nebular/dms/repfeepool/ListUsedRes.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.PageVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/10/21 16:43
 **/
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "前段页面查货补扣减记录返回的vo")
public class ListUsedRes extends PageVo {

    @ApiModelProperty(value = "编码")
    private String code;

    @ApiModelProperty(value = "销售公司名字")
    private String saleConpaneyName;

    @ApiModelProperty(value = "类型中文")
    private Integer type;

    @CrmDict(typeCode="fee_adjust_type",dictCodeField="type")
    @ApiModelProperty(value = "类型中文")
    private String typeName;

    @ApiModelProperty(value = "业务编号")
    private String businessCode;

    @ApiModelProperty(value = "产品编码")
    private String productCode;

    @ApiModelProperty(value = "产品名称")
    private String productName;

    @ApiModelProperty(value = "单价")
    private BigDecimal price;

    @ApiModelProperty(value = "单位")
    private String unit;

    @ApiModelProperty(value = "数量")
    private BigDecimal num;

    @ApiModelProperty(value = "日期")
    private String happenDate;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "附件地址")
    private List<String> fileUrls = new ArrayList<>();

    @ApiModelProperty(value = "创建时间（日期+时间）")
    private String createTime;

    @ApiModelProperty(value = "创建人名称")
    private String createName;
}
